@@ -1,6 +1,6 @@
-from os.path import dirname, abspath
+from os.path import abspath, dirname
 
 ROOT_DIR = dirname(abspath(__file__))
 
 __version__ = "1.0.3"
-__author__ = 'Moxie'
\ No newline at end of file
+__author__ = "Moxie"
